@@ -9,13 +9,13 @@
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-
+#include "bhpm_Rdefines.h"
 #include "bhpm1a_poisson_mc_hier2_lev0.h"
 #include "bhpm1a_poisson_mc_hier2_lev1.h"
 
 using namespace std;
 
-static const char *rcsId = "$Id: bhpm1a_poisson_mc_hier2_lev1.cpp,v 1.9 2019/04/28 13:51:58 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: bhpm1a_poisson_mc_hier2_lev1.cpp,v 1.9 2019/04/28 13:51:58 clb13102 Exp clb13102 $";
 
 //
 // The way the code is set up means we can't allow the body-systems to change from
@@ -899,7 +899,7 @@ SEXP bhpm1a_poisson_mc_hier2_lev1::getL2Samples(double*** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -918,13 +918,13 @@ SEXP bhpm1a_poisson_mc_hier2_lev1::getL2Samples(double*** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 3));
+	PROTECT(dim = Rf_allocVector(INTSXP, 3));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -936,7 +936,7 @@ SEXP bhpm1a_poisson_mc_hier2_lev1::getL2Samples(double**** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gNumComparators * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gNumComparators * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -960,14 +960,14 @@ SEXP bhpm1a_poisson_mc_hier2_lev1::getL2Samples(double**** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 4));
+	PROTECT(dim = Rf_allocVector(INTSXP, 4));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gNumComparators;
 	INTEGER(dim)[3] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
