@@ -9,14 +9,14 @@
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-
+#include "bhpm_Rdefines.h"
 #include "bhpm1a_poisson_mc_hier2_lev0.h"
 #include "bhpm1a_poisson_mc_hier3_lev0.h"
 #include "bhpm1a_poisson_mc_hier3_lev2.h"
 
 using namespace std;
 
-static const char *rcsId = "$Id: bhpm1a_poisson_mc_hier3_lev2.cpp,v 1.7 2019/05/14 09:29:48 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: bhpm1a_poisson_mc_hier3_lev2.cpp,v 1.7 2019/05/14 09:29:48 clb13102 Exp clb13102 $";
 
 bhpm1a_poisson_mc_hier3_lev2::bhpm1a_poisson_mc_hier3_lev2()
 {
@@ -713,7 +713,7 @@ SEXP bhpm1a_poisson_mc_hier3_lev2::getL3Samples(double** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -727,12 +727,12 @@ SEXP bhpm1a_poisson_mc_hier3_lev2::getL3Samples(double** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 2));
+	PROTECT(dim = Rf_allocVector(INTSXP, 2));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -744,7 +744,7 @@ SEXP bhpm1a_poisson_mc_hier3_lev2::getL3Samples(double*** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gNumComparators * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gNumComparators * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -763,13 +763,13 @@ SEXP bhpm1a_poisson_mc_hier3_lev2::getL3Samples(double*** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 3));
+	PROTECT(dim = Rf_allocVector(INTSXP, 3));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gNumComparators;
 	INTEGER(dim)[2] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
