@@ -10,14 +10,14 @@
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-
+#include "bhpm_Rdefines.h"
 #include "bhpm1a_poisson_mc_hier2_lev0.h"
 #include "bhpm1a_poisson_mc_hier3_lev0.h"
 #include "bhpmBB_poisson_mc_hier3_lev0.h"
 
 using namespace std;
 
-static const char *rcsId = "$Id: bhpmBB_poisson_mc_hier3_lev0.cpp,v 1.9 2019/04/28 13:51:58 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: bhpmBB_poisson_mc_hier3_lev0.cpp,v 1.9 2019/04/28 13:51:58 clb13102 Exp clb13102 $";
 
 const char* bhpmBB_poisson_mc_hier3_lev0::sMonitor_pi = "pi";
 const char* bhpmBB_poisson_mc_hier3_lev0::sMonitor_alpha_pi = "alpha.pi";
@@ -200,9 +200,9 @@ void bhpmBB_poisson_mc_hier3_lev0::initPMWeights(SEXP pm_weights)
 	SEXP sj = R_NilValue;
 	SEXP sGroup = R_NilValue;
 
-	if (len && isNewList(pm_weights)) {
+	if (len && Rf_isNewList(pm_weights)) {
 
-		SEXP names = getAttrib(pm_weights, R_NamesSymbol);
+		SEXP names = Rf_getAttrib(pm_weights, R_NamesSymbol);
 
 		for (i = 0; i < len; i++) {
 			if (strcmp(sColPMweight, CHAR(STRING_ELT(names, i))) == 0) {
@@ -311,7 +311,7 @@ void bhpmBB_poisson_mc_hier3_lev0::initSimParams(SEXP sSim_Params)
 
 	int len = Rf_length(sSim_Params);
 
-	if (len && isNewList(sSim_Params)) {
+	if (len && Rf_isNewList(sSim_Params)) {
 
 		SEXP sVariables = R_NilValue;
 		SEXP sParams = R_NilValue;
@@ -322,7 +322,7 @@ void bhpmBB_poisson_mc_hier3_lev0::initSimParams(SEXP sSim_Params)
 		SEXP sC_index = R_NilValue;
 		SEXP sGroup = R_NilValue;
 
-		SEXP names = getAttrib(sSim_Params, R_NamesSymbol);
+		SEXP names = Rf_getAttrib(sSim_Params, R_NamesSymbol);
 
 		for (i = 0; i < len; i++) {
 			if (strcmp(sColValue, CHAR(STRING_ELT(names, i))) == 0) {
@@ -425,9 +425,9 @@ void bhpmBB_poisson_mc_hier3_lev0::initGlobalSimParams(SEXP sSim_Type, SEXP sGlo
 		gSimType = eSim_Type_SLICE;
 	}
 
-    if (len > 0 && isNewList(sGlobal_Sim_Params)) {
+    if (len > 0 && Rf_isNewList(sGlobal_Sim_Params)) {
 
-        SEXP names = getAttrib(sGlobal_Sim_Params, R_NamesSymbol);
+        SEXP names = Rf_getAttrib(sGlobal_Sim_Params, R_NamesSymbol);
 
         int i = 0;
 
@@ -987,9 +987,9 @@ void bhpmBB_poisson_mc_hier3_lev0::initMonitor(SEXP sMonitor)
     SEXP sVariables = R_NilValue;
     SEXP sValues = R_NilValue;
 
-    if (isNewList(sMonitor)) {
+    if (Rf_isNewList(sMonitor)) {
 
-        SEXP names = getAttrib(sMonitor, R_NamesSymbol);
+        SEXP names = Rf_getAttrib(sMonitor, R_NamesSymbol);
 
         int i = 0;
 
@@ -1875,7 +1875,7 @@ SEXP bhpmBB_poisson_mc_hier3_lev0::getL3Accept(int** &data)
 	SEXP acc = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(acc = allocVector(INTSXP, gChains * gNumClusters));
+	PROTECT(acc = Rf_allocVector(INTSXP, gChains * gNumClusters));
 
 	int i = 0;
 	int c = 0;
@@ -1888,12 +1888,12 @@ SEXP bhpmBB_poisson_mc_hier3_lev0::getL3Accept(int** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 2));
+	PROTECT(dim = Rf_allocVector(INTSXP, 2));
 
 	INTEGER(dim)[0] = gNumClusters;
 	INTEGER(dim)[1] = gChains;
 
-	setAttrib(acc, R_DimSymbol, dim);
+	Rf_setAttrib(acc, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -1905,7 +1905,7 @@ SEXP bhpmBB_poisson_mc_hier3_lev0::getL3Accept(int*** &data)
 	SEXP acc = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(acc = allocVector(INTSXP, gChains * gNumComparators * gNumClusters));
+	PROTECT(acc = Rf_allocVector(INTSXP, gChains * gNumComparators * gNumClusters));
 
 	int i = 0;
 	int c = 0;
@@ -1921,13 +1921,13 @@ SEXP bhpmBB_poisson_mc_hier3_lev0::getL3Accept(int*** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 3));
+	PROTECT(dim = Rf_allocVector(INTSXP, 3));
 
 	INTEGER(dim)[0] = gNumClusters;
 	INTEGER(dim)[1] = gNumComparators;
 	INTEGER(dim)[2] = gChains;
 
-	setAttrib(acc, R_DimSymbol, dim);
+	Rf_setAttrib(acc, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
