@@ -10,7 +10,7 @@
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-
+#include "bhpm_Rdefines.h"
 #include "bhpm1a_poisson_mc_hier2_lev0.h"
 #include "bhpm1a_poisson_mc_hier3_lev0.h"
 #include "bhpmBB_poisson_mc_hier3_lev0.h"
@@ -19,7 +19,7 @@
 
 using namespace std;
 
-static const char *rcsId = "$Id: bhpmBB_poisson_mc_hier3_lev1.cpp,v 1.10 2019/05/14 09:29:48 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: bhpmBB_poisson_mc_hier3_lev1.cpp,v 1.10 2019/05/14 09:29:48 clb13102 Exp clb13102 $";
 
 bhpmBB_poisson_mc_hier3_lev1::bhpmBB_poisson_mc_hier3_lev1()
 {
@@ -318,12 +318,12 @@ void bhpmBB_poisson_mc_hier3_lev1::initL2Samples()
 
 		for (t = 0; t < gNumComparators; t++) {
 
-		if (retainSamples(iMonitor_mu_theta))
-			mu_theta_samples[c][t] = new double *[gMaxBs];
-		if (retainSamples(iMonitor_sigma2_theta))
-			sigma2_theta_samples[c][t] = new double *[gMaxBs];
-		if (retainSamples(iMonitor_pi))
-			gPi_samples[c][t] = new double *[gMaxBs];
+			if (retainSamples(iMonitor_mu_theta))
+				mu_theta_samples[c][t] = new double *[gMaxBs];
+			if (retainSamples(iMonitor_sigma2_theta))
+				sigma2_theta_samples[c][t] = new double *[gMaxBs];
+			if (retainSamples(iMonitor_pi))
+				gPi_samples[c][t] = new double *[gMaxBs];
 
 			for (b = 0; b < gNumBodySys[l]; b++) {
 				if (retainSamples(iMonitor_mu_theta))
@@ -1540,7 +1540,7 @@ SEXP bhpmBB_poisson_mc_hier3_lev1::getL2Samples(double*** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1559,13 +1559,13 @@ SEXP bhpmBB_poisson_mc_hier3_lev1::getL2Samples(double*** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 3));
+	PROTECT(dim = Rf_allocVector(INTSXP, 3));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -1577,7 +1577,7 @@ SEXP bhpmBB_poisson_mc_hier3_lev1::getL2Samples(double**** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gNumComparators * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gNumComparators * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1602,14 +1602,14 @@ SEXP bhpmBB_poisson_mc_hier3_lev1::getL2Samples(double**** &data)
 	delete [] data;
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 4));
+	PROTECT(dim = Rf_allocVector(INTSXP, 4));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gNumComparators;
 	INTEGER(dim)[3] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
